@@ -178,7 +178,7 @@ class NativeRuntime(object):
 
     def execute(self):
 
-        self._logger('Workflow starting (run-id %s):' % self._run_id,
+        self._logger('Flow starting (id %s):' % self._run_id,
                      system_msg=True)
 
         if self._params_task:
@@ -214,12 +214,12 @@ class NativeRuntime(object):
                     self._logger(msg, system_msg=True)
 
         except KeyboardInterrupt as ex:
-            self._logger('Workflow interrupted.', system_msg=True, bad=True)
+            self._logger('Flow interrupted.', system_msg=True, bad=True)
             self._killall()
             exception = ex
             raise
         except Exception as ex:
-            self._logger('Workflow failed.', system_msg=True, bad=True)
+            self._logger('Flow failed.', system_msg=True, bad=True)
             self._killall()
             exception = ex
             raise
